@@ -255,8 +255,8 @@ This is especially useful if the particular format isn't identified by
 a magic number and doesn't have the 'typical' extension or you want to
 avoid the check of the magic number if your data comes in from a pipe.
 The function returns a pdl of the appropriate type upon completion.
-Option parsing uses the L<PDL::Options> module and therefore supports
-minimal options matching.
+Option parsing uses the L<PDL::Options|PDL::Options> module and
+therefore supports minimal options matching.
 
 You can also read directly into an existing pdl that has to have the
 right size(!). This can come in handy when you want to read a sequence
@@ -366,8 +366,9 @@ the image format that is being written. Valid options are (key
    COLOR      => 'bw',         # specify color conversion
    LUT        => $lut,         # use color table information
 
-Option parsing uses the L<PDL::Options> module and therefore supports
-minimal options matching. A detailed explanation of supported options follows.
+Option parsing uses the L<PDL::Options|PDL::Options> module and
+therefore supports minimal options matching. A detailed explanation of
+supported options follows.
 
 =over 7
 
@@ -522,7 +523,7 @@ If the image is in one of the standard RGB formats, then you get back
 data in (<X>,<Y>,<RGB-index>) format -- that is to say, the third dim
 contains the color information.  That allows you to do simple indexing
 into the image without knowing whether it is color or not -- if present,
-the RGB information is silently threaded over.  (Contrast L<rpic>, which
+the RGB information is silently threaded over.  (Contrast L<rpic|rpic>, which
 munges the information by putting the RGB index in the 0th dim, screwing
 up subsequent threading operations).
 
@@ -535,7 +536,7 @@ automatically uncompressed before reading.
 
 OPTIONS
 
-The same as L<rpic>, which is used as an engine:
+The same as L<rpic|rpic>, which is used as an engine:
 
 =over 3
 
